@@ -223,7 +223,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! revai = "0.2.0"
+//! revai = "0.2.1"
 //! ```
 //!
 //! ## Basic example
@@ -299,6 +299,7 @@ use std::env;
 /// Entrypoint for interacting with the API client.
 #[derive(Clone)]
 pub struct Client {
+    host: String,
     token: String,
 
     client: reqwest::Client,
@@ -315,6 +316,7 @@ impl Client {
         let client = reqwest::Client::builder().build();
         match client {
             Ok(c) => Client {
+                host: DEFAULT_HOST.to_string(),
                 token: token.to_string(),
 
                 client: c,
@@ -323,6 +325,16 @@ impl Client {
         }
     }
 
+    /// Override the default host for the client.
+    pub fn with_host<H>(&self, host: H) -> Self
+    where
+        H: ToString,
+    {
+        let mut c = self.clone();
+        c.host = host.to_string();
+        c
+    }
+
     /// Create a new Client struct from environment variables. It
     /// takes a type that can convert into
     /// an &str (`String` or `Vec<u8>` for example). As long as the function is
@@ -351,7 +363,7 @@ impl Client {
         let u = if uri.starts_with("https://") {
             uri.to_string()
         } else {
-            (DEFAULT_HOST.to_string() + uri).to_string()
+            (self.host.clone() + uri).to_string()
         };
         let (url, auth) = self.url_and_auth(&u).await?;
 
@@ -484,7 +496,7 @@ impl Client {
         let u = if uri.starts_with("https://") {
             uri.to_string()
         } else {
-            (DEFAULT_HOST.to_string() + uri).to_string()
+            (self.host.clone() + uri).to_string()
         };
         let (url, auth) = self.url_and_auth(&u).await?;
 
@@ -564,7 +576,7 @@ impl Client {
         let u = if uri.starts_with("https://") {
             uri.to_string()
         } else {
-            (DEFAULT_HOST.to_string() + uri).to_string()
+            (self.host.clone() + uri).to_string()
         };
         let (url, auth) = self.url_and_auth(&u).await?;
 
@@ -639,7 +651,7 @@ impl Client {
         let u = if uri.starts_with("https://") {
             uri.to_string()
         } else {
-            (DEFAULT_HOST.to_string() + uri).to_string()
+            (self.host.clone() + uri).to_string()
         };
         let (url, auth) = self.url_and_auth(&u).await?;
 
@@ -732,12 +744,8 @@ impl Client {
     where
         D: serde::de::DeserializeOwned + 'static + Send,
     {
-        self.request_entity(
-            http::Method::GET,
-            &(DEFAULT_HOST.to_string() + uri),
-            message,
-        )
-        .await
+        self.request_entity(http::Method::GET, &(self.host.to_string() + uri), message)
+            .await
     }
 
     #[allow(dead_code)]
@@ -777,7 +785,7 @@ impl Client {
     where
         D: serde::de::DeserializeOwned + 'static + Send,
     {
-        self.request_with_links(http::Method::GET, &(DEFAULT_HOST.to_string() + uri), None)
+        self.request_with_links(http::Method::GET, &(self.host.to_string() + uri), None)
             .await
     }
 
@@ -798,12 +806,8 @@ impl Client {
     where
         D: serde::de::DeserializeOwned + 'static + Send,
     {
-        self.request_entity(
-            http::Method::POST,
-            &(DEFAULT_HOST.to_string() + uri),
-            message,
-        )
-        .await
+        self.request_entity(http::Method::POST, &(self.host.to_string() + uri), message)
+            .await
     }
 
     #[allow(dead_code)]
@@ -811,12 +815,8 @@ impl Client {
     where
         D: serde::de::DeserializeOwned + 'static + Send,
     {
-        self.request_entity(
-            http::Method::PATCH,
-            &(DEFAULT_HOST.to_string() + uri),
-            message,
-        )
-        .await
+        self.request_entity(http::Method::PATCH, &(self.host.to_string() + uri), message)
+            .await
     }
 
     #[allow(dead_code)]
@@ -824,12 +824,8 @@ impl Client {
     where
         D: serde::de::DeserializeOwned + 'static + Send,
     {
-        self.request_entity(
-            http::Method::PUT,
-            &(DEFAULT_HOST.to_string() + uri),
-            message,
-        )
-        .await
+        self.request_entity(http::Method::PUT, &(self.host.to_string() + uri), message)
+            .await
     }
 
     #[allow(dead_code)]
@@ -839,7 +835,7 @@ impl Client {
     {
         self.request_entity(
             http::Method::DELETE,
-            &(DEFAULT_HOST.to_string() + uri),
+            &(self.host.to_string() + uri),
             message,
         )
         .await
